@@ -39,9 +39,9 @@ class TestDaemon(object):
         conn.set_request_cb(self.request_cb, ['print', 'this', 'out'])
         conn.set_close_cb(self.close_cb, ['conn', 'closed'])
 
-def main(port):
+def main(**kwargs):
     test = TestDaemon()
-    server = STOMPServer("localhost", port)
+    server = STOMPServer(kwargs['domain'], kwargs['port'])
     server.set_connect_cb(test.connect_cb)
     server.start()
 
